@@ -1,6 +1,7 @@
 package Pcore::API::Facebook::Marketing;
 
 use Pcore -role, -const, -export;
+use Pcore::Util::Scalar qw[is_plain_coderef];
 
 our $EXPORT = {
     ALL                     => [qw[$FB_ADACC_STATUS_TEXT $FB_ADACC_DISABLE_REASON_TEXT]],
@@ -11,7 +12,7 @@ our $EXPORT = {
 # https://developers.facebook.com/docs/marketing-api/
 
 # https://developers.facebook.com/docs/graph-api/changelog
-const our $VER => 3.3;
+const our $API_VER => 3.3;
 
 const our $FB_ADACC_STATUS_ACTIVE              => 1;
 const our $FB_ADACC_STATUS_DISABLED            => 2;
@@ -63,42 +64,81 @@ const our $FB_ADACC_DISABLE_REASON_TEXT => {
 
 # ADACCOUNTS
 # https://developers.facebook.com/docs/marketing-api/reference/ad-account/
-sub get_adaccounts ( $self, $user_id, $cb = undef ) {
+# metadata, fields, limit
+# fields => 'account_id,id,name,age,amount_spent,balance,currency,account_status,disable_reason,is_prepay_account,spend_cap,min_campaign_group_spend_cap,min_daily_budget,current_unbilled_spend,next_bill_date,min_billing_threshold,max_billing_threshold,can_repay_now,can_pay_now,adtrust_dsl'
+sub get_adaccounts ( $self, $user_id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
 
-    # '/act_' . $act_id . '/?_reqName=adaccount&_reqSrc=AdsAccountDataLoader&include_headers=false&locale=ru_RU&method=get&pretty=0&suppress_http_code=1
+    my %args = @args;
 
-    # return $self->_req( 'GET', "v$VER/act_367728070752967", { metadata => 1 }, undef, $cb );
-
-    # return $self->_req( 'GET', "v$VER/$user_id/adaccounts", { fields => 'account_id,id,name,adtrust_dsl' }, undef, $cb );
-
-    return $self->_req( 'GET', "v$VER/$user_id/adaccounts", { fields => 'account_id,id,name,age,amount_spent,balance,currency,account_status,disable_reason,is_prepay_account,spend_cap,min_campaign_group_spend_cap,min_daily_budget,current_unbilled_spend,next_bill_date,min_billing_threshold,max_billing_threshold,can_repay_now,can_pay_now,adtrust_dsl' }, undef, $cb );
+    return $self->_req( 'GET', "v$API_VER/$user_id/adaccounts", \%args, undef, $cb );
 }
 
 # CAMPAIGNS
 # https://developers.facebook.com/docs/marketing-api/reference/ad-campaign-group
-sub get_campaigns ( $self, $adaccount_id, $cb = undef ) {
+# fields => 'id,budget_remaining,configured_status,daily_budget,lifetime_budget,effective_status,name',
+sub get_campaigns ( $self, $adaccount_id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
+
+    my %args = @args;
+
     $adaccount_id = "act_$adaccount_id" if substr( $adaccount_id, 0, 4 ) ne 'act_';
 
-    return $self->_req( 'GET', "v$VER/$adaccount_id/campaigns", { fields => 'id,budget_remaining,configured_status,daily_budget,lifetime_budget,effective_status,name', }, undef, $cb );
+    return $self->_req( 'GET', "v$API_VER/$adaccount_id/campaigns", \%args, undef, $cb );
 }
 
 # ADSETS
 # https://developers.facebook.com/docs/marketing-api/reference/ad-campaign/
-sub get_adsets ( $self, $adaccount_id, $cb = undef ) {
+# fields => 'id,name,daily_budget,effective_status,lifetime_budget,budget_remaining,campaign'
+sub get_adsets ( $self, $adaccount_id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
+
+    my %args = @args;
+
     $adaccount_id = "act_$adaccount_id" if substr( $adaccount_id, 0, 4 ) ne 'act_';
 
-    return $self->_req( 'GET', "v$VER/$adaccount_id/adsets", { fields => 'id,name,daily_budget,effective_status,lifetime_budget,budget_remaining,campaign', }, undef, $cb );
+    return $self->_req( 'GET', "v$API_VER/$adaccount_id/adsets", \%args, undef, $cb );
 }
 
-sub get_adset ( $self, $adset_id, $cb = undef ) {
-    return $self->_req( 'GET', "v$VER/$adset_id", { fields => 'id,name,daily_budget,effective_status,lifetime_budget,budget_remaining', }, undef, $cb );
+# fields => 'id,name,daily_budget,effective_status,lifetime_budget,budget_remaining
+sub get_adset ( $self, $adset_id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
+
+    my %args = @args;
+
+    return $self->_req( 'GET', "v$API_VER/$adset_id", \%args, undef, $cb );
 }
 
 # INSIGHTS
 # https://developers.facebook.com/docs/marketing-api/insights
 # https://developers.facebook.com/docs/marketing-api/reference/ads-insights/
-sub get_insights ( $self, $id, $cb = undef ) {
-    return $self->_req( 'GET', "v$VER/$id/insights", { fields => 'impressions,ad_id,clicks,spend,cpc,ctr,reach,adset_name,adset_id', }, undef, $cb );
+# fields => 'impressions,ad_id,clicks,spend,cpc,ctr,reach,adset_name,adset_id'
+sub get_insights ( $self, $id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
+
+    my %args = @args;
+
+    return $self->_req( 'GET', "v$API_VER/$id/insights", \%args, undef, $cb );
+}
+
+# get ads
+# limit, fields
+sub get_ads ( $self, $id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
+
+    my %args = @args;
+
+    return $self->_req( 'GET', "v$API_VER/$id/ads", \%args, undef, $cb );
+}
+
+# get ad by id
+# metadata, limit, fields
+sub get_ad ( $self, $ad_id, @args ) {
+    my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
+
+    my %args = @args;
+
+    return $self->_req( 'GET', "v$API_VER/$ad_id", \%args, undef, $cb );
 }
 
 1;
